/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GetJasmineNotifsJMSCommand.as 6516 2010-05-25 17:23:36Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.notification.command
{

import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import mx.collections.ArrayCollection;
import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.FaultEvent;
import mx.rpc.events.ResultEvent;

import org.ow2.jasmine.monitoring.eos.common.controls.ServerSideException;
import org.ow2.jasmine.monitoring.eos.common.events.ServerSideExceptionEvent;
import org.ow2.jasmine.monitoring.eos.notification.business.*;
import org.ow2.jasmine.monitoring.eos.notification.model.NotificationModelLocator;

[Event(name="serverSideException", type="org.ow2.jasmine.monitoring.eos.common.events.ServerSideExceptionEvent")]
public class GetJasmineNotifsJMSCommand implements ICommand, IResponder
{

    private static var failedTimes : int = 0;

    public function GetJasmineNotifsJMSCommand()
    {

    }

    public function execute(event:CairngormEvent):void
    {

        var delegate:IGetJasmineNotifJMSDelegate = NotificationModelLocator.getInstance().getGetJasmineNotifJMSDelegate();
        delegate.responder = this;
        delegate.getNotifsFromTopic();

    }

    public function result(data:Object):void
    {

        GetJasmineNotifsJMSCommand.failedTimes = 0;

        var model:NotificationModelLocator = NotificationModelLocator.getInstance();
        var result:ArrayCollection = (data as ResultEvent).result as ArrayCollection;

        if (result.length != 0) {
            // only add results if there are results !!
            model.jasmineNotifsFromJMS = result;
        }

    }

    public function fault(info:Object):void
    {

        GetJasmineNotifsJMSCommand.failedTimes++;

        if (GetJasmineNotifsJMSCommand.failedTimes == 3) {
            // Retrieve the fault event
            var faultEvent : FaultEvent = FaultEvent(info);

            // Tell the view and let it handle this
            var serverSideExceptionEvent : ServerSideExceptionEvent =
                new ServerSideExceptionEvent(
                    "serverSideException",
                    new ServerSideException("Error while getting notification from the JMS topic.",
                                            "The operation could not be performed."
                                            + "\n" + faultEvent.fault.faultCode
                                            + "\n" + faultEvent.fault.faultString,
                                            faultEvent.fault.getStackTrace()));
            CairngormEventDispatcher.getInstance().dispatchEvent(serverSideExceptionEvent);
        }
    }

}
}
